import { identity } from './types';
import { ComponentDependencies } from './components/component';
/**
 * Virtual slide component.
 */
export declare class Slide {
    private _frame;
    private _imports;
    idx: number;
    ref: HTMLElement;
    isMounted: boolean;
    isActive: boolean;
    isClone: boolean;
    position: number;
    private _hasChanged;
    private _html;
    private _transitionEndCallback;
    constructor(html: string | HTMLElement, _frame: HTMLElement, _imports: ComponentDependencies);
    set<T extends Extract<keyof this, 'isActive' | 'position'>>(property: T, value: this[T]): Slide;
    /**
     * Render and mount slide into DOM.
     *
     * @param prepend Either prepend slide to frame DOM element or append.
     */
    mount(prepend?: boolean): void;
    /**
     * Unmount and remove slide from DOM.
     */
    unmount(): void;
    /**
     * Clone slide and return clone.
     *
     * @returns Cloned slide instance.
     */
    clone(): Slide;
    /**
     * Start transition.
     *
     * @param value Position to translate to. Unit (px, %,..) has to be given.
     * @param easing Enable or disable transition easing.
     * @param done Callback function after transition has ended.
     */
    translate(xPosition: string, { ease, done }?: {
        ease?: boolean;
        done?: identity;
    }): void;
    private _render;
    private _bindEvents;
    private _unbindEvents;
    private _update;
    private _setAttributes;
    private _onTransitionEnd;
}
