export declare function stop(e: MouseEvent | TouchEvent): void;
export declare type EventHandler = (...args: unknown[]) => void;
export declare type EventTarget = (Window & typeof globalThis) | Element;
export declare type EventOptions = boolean | AddEventListenerOptions;
export declare class Event {
    /**
     * Store all event this.data.
     */
    private _handlers;
    /**
     * Subscribe the given event(s).
     *
     * @param events  - An event name. Use space to separate multiple events.
     *                  Also, namespace is accepted by dot, such as 'resize.{namespace}'.
     * @param handler - A callback function.
     * @param element - Optional. Native event will be listened to when this arg is provided.
     * @param opts - Optional. Options for addEventListener.
     */
    on(events: string, handler: EventHandler, element?: EventTarget, opts?: EventOptions): Event;
    on(events: {
        [event: string]: EventHandler;
    }, element?: EventTarget, opts?: EventOptions): Event;
    /**
     * Unsubscribe the given event(s).
     *
     * @param events - A event name or names split by space.
     * @param element - Optional. removeEventListener() will be called when this arg is provided.
     */
    off(events: string, handler: EventHandler, element?: EventTarget): Event;
    off(events: {
        [event: string]: EventHandler;
    }, element?: EventTarget): Event;
    /**
     * Emit an event.
     * This method is only for custom events.
     *
     * @param event - An event name.
     * @param args  - Any number of arguments passed to handlers.
     */
    emit(event: string, ...args: unknown[]): void;
    /**
     * Clear event this.data.
     */
    destroy(): void;
    /**
     * Remove the registered event listener.
     *
     * @param item - An object containing event this.data.
     */
    private _unroll;
    private _addEvent;
    private _removeEvent;
}
